bl_info = {
    "name": "House",
    "description": "Klasický domecek v2.0",
    "author": "Jiri Chludil",
    "version": (1, 0, 0),
    "blender": (2, 8, 0),
    "location": "View3D > Add > Mesh > House",
    "warning": "",
    "wiki_url": "http://edux.fit.cvut.cz/courses/BI-PGA",
    "category": "Add Mesh"
}

import bpy
from bpy_extras import object_utils
from math import *
from mathutils import *

def add_house(size = (1.0 ,1.0 ,1.0 ), roof = 1):
    verts = []
    edges = []
    faces = []
    size_x = size[0] / 2.0
    size_y = size[1] / 2.0
    size_z = size[2] / 2.0
    verts.append((-size_x, -size_y, -size_z))
    verts.append(( size_x, -size_y, -size_z))
    verts.append(( size_x, size_y, -size_z))
    verts.append((-size_x, size_y, -size_z))
    verts.append((-size_x, -size_y, size_z))
    verts.append(( size_x, -size_y, size_z))
    verts.append(( size_x, size_y, size_z))
    verts.append((-size_x, size_y, size_z))
    verts.append((-size_x, 0, size_z+roof))
    verts.append(( size_x, 0, size_z+roof))
    faces.append([0,3,2,1])
    faces.append([0,1,5,4])
    faces.append([1,2,6,5])
    faces.append([2,3,7,6])
    faces.append([3,0,4,7])
    faces.append([4,5,9,8])
    faces.append([6,7,8,9])
    faces.append([5,6,9])
    faces.append([4,8,7])
    return verts, edges, faces

def create_mesh_object(context, verts, edges, faces, name):
    mesh = bpy.data.meshes.new(name)
    mesh.from_pydata(verts, edges, faces)
    mesh.update()
    
    return object_utils.object_data_add(context, mesh, operator=None)


class MyHouse(bpy.types.Operator):
    bl_idname = "object.house"
    bl_label = "House"
    bl_options = {'REGISTER', 'UNDO'}
    
    size = bpy.props.FloatVectorProperty(
        name = 'Size',
        description = 'Size of base house',
        subtype = 'XYZ',
        default=(1.0, 1.0, 1.0),
    )
    
    roof = bpy.props.FloatProperty(
       name = 'Roof',
       description = 'Height of roof',
       default = 1,
       min = 0,
       max = 2,
       step = 25,
    )
    
    
    
    
    
    def execute(self, context):
        verts, edges, faces = add_house(self.size, self.roof)
        obj = create_mesh_object(context, verts, edges, faces, "House")     
        return {'FINISHED'}
    
    
    
    
classes = [MyHouse]

def menu_func(self, context):
    self.layout.operator(MyHouse.bl_idname)

def register():
   from bpy.utils import register_class
   for cls in classes:
       register_class(cls)
   bpy.types.VIEW3D_MT_mesh_add.append(menu_func)       

def unregister():
    from bpy.utils import unregister_class
    for cls in reversed(classes):
       unregister_class(cls)
    bpy.types.VIEW3D_MT_mesh_add.remove(menu_func)
     
if __name__ == "__main__":
    register()
    